summaryrefslogtreecommitdiffstats
path: root/libktorrent/interfaces/prefpageinterface.h
diff options
context:
space:
mode:
Diffstat (limited to 'libktorrent/interfaces/prefpageinterface.h')
-rw-r--r--libktorrent/interfaces/prefpageinterface.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/libktorrent/interfaces/prefpageinterface.h b/libktorrent/interfaces/prefpageinterface.h
index b27390e..850a344 100644
--- a/libktorrent/interfaces/prefpageinterface.h
+++ b/libktorrent/interfaces/prefpageinterface.h
@@ -58,9 +58,9 @@ namespace kt
/**
* Create the actual widget.
* @param tqparent The tqparent of the widget
*/
- virtual void createWidget(TQWidget* tqparent)=0;
+ virtual void createWidget(TQWidget* parent)=0;
/**
* Update all data on the widget, gets called before
@@ -58,9 +58,9 @@ namespace kt
/**
* Create the actual widget.
- * @param tqparent The tqparent of the widget
+ * @param parent The parent of the widget
*/